@@ -139,28 +139,28 @@ use vars qw(@ISA @EXPORT $VERSION);
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw(transform);
-$VERSION = '1.002';
+$VERSION = '1.004'; # Saturday 21 March 2009
 
 =head1 Description
 
 Generate and process all the all the transformations of a list using the
 standard Perl metaphor. 
 
-C<permute()> returns the number of transformations in both scalar and
+C<transform()> returns the number of transformations in both scalar and
 array context.
 
-Its easy to use and fast. Its written in 100% Pure Perl.
+C<transform()> is easy to use and fast. It is written in 100% Pure Perl.
 
 Please note that the order in which the transformations are generated is
 not guaranteed, so please do not rely on it.
 
-The parameters to C<permute()> are:
+The parameters to C<transform()> are:
 
 1: The code to be executed for each transformation.
 
-2: The list to be transformed. This list is transformed as specified by
-the transformations. Each transformation of the list is handed to the
-code supplied in parameter 1 to be processed.
+2: A reference to the list to be transformed. This list is transformed
+as specified by the transformations. Each transformation of the list is
+handed to the code supplied in parameter 1 to be processed.
 
 3: One or more transformations to be applied to the list. The
 transformations are applied repeatedly in all orders until no new
@@ -226,9 +226,17 @@ http://www.handybackup.com
 
 =head1 See Also
 
-L<Math::Permute::List>
-L<Math::Disarrange::List>
-L<Math::Subsets::List>
+=over
+
+=item L<Math::Cartesian::List>
+
+=item L<Math::Disarrange::List>
+
+=item L<Math::Permute::List>
+
+=item L<Math::Subsets::List>
+
+=back
 
 =head1 Copyright
 
